@@ -1,9 +1,10 @@
 //! endpoints for working with Monzo pots
 
-use crate::endpoints::utils::empty_string_as_none;
 use chrono::{DateTime, Utc};
 use serde::Deserialize;
 
+use crate::endpoints::utils::empty_string_as_none;
+
 mod list;
 pub(crate) use list::Request as List;
 mod deposit;
@@ -12,7 +13,7 @@ mod withdraw;
 pub(crate) use withdraw::Request as Withdraw;
 
 /// Representation of a Monzo pot
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize, Debug, Clone, PartialEq)]
 #[non_exhaustive]
 pub struct Pot {
     /// Unique ID for this Monzo pot
